@@ -1,14 +1,25 @@
 from os import error
 from fastapi import FastAPI
 from fastapi import APIRouter, Request, Response
+from fastapi.staticfiles import StaticFiles
+from starlette.responses import FileResponse
 from beastiary.api.endpoints import runs, samples
 
 app = FastAPI()
 
 
 @app.get("/")
-async def root():
-    return {"message": "Welcome to the BEASTIARY"}
+async def index():
+    return FileResponse("beastiary/webapp-dist/index.html")
+
+
+api_router = APIRouter(prefix="/api")
+api_router.include_router(samples.router, prefix="/samples", tags=["samples"])
+api_router.include_router(runs.router, prefix="/runs", tags=["runs"])
+app.include_router(api_router)
+
+
+app.mount("/", StaticFiles(directory="beastiary/webapp-dist"))
 
 
 @app.middleware("http")
@@ -21,7 +32,9 @@ async def add_process_time_header(request: Request, call_next):
     return response
 
 
-api_router = APIRouter(prefix="/api")
-api_router.include_router(samples.router, prefix="/samples", tags=["samples"])
-api_router.include_router(runs.router, prefix="/runs", tags=["runs"])
-app.include_router(api_router)
+@app.middleware("http")
+async def add_custom_header(request: Request, call_next):
+    response = await call_next(request)
+    if response.status_code == 404:
+        return FileResponse("beastiary/webapp-dist/index.html")
+    return response
